==> fsl_5.0.4.orig.tar.gz: fsl-5.0.4.orig/src/feat5/generateConfounds.cc <==
/*    Copyright Matthew Webster (C) 2012 University of Oxford  */

/*  Part of FSL - FMRIB's Software Library
    http://www.fmrib.ox.ac.uk/fsl
    fsl@fmrib.ox.ac.uk
    
    Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
    Imaging of the Brain), Department of Clinical Neurology, Oxford
    University, Oxford, UK
    
    
    LICENCE
    
    FMRIB Software Library, Release 5.0 (c) 2012, The University of
    Oxford (the "Software")
    
    The Software remains the property of the University of Oxford ("the
    University").
    
    The Software is distributed "AS IS" under this Licence solely for
    non-commercial use in the hope that it will be useful, but in order
    that the University as a charitable foundation protects its assets for
    the benefit of its educational and research purposes, the University
    makes clear that no condition is made or to be implied, nor is any
    warranty given or to be implied, as to the accuracy of the Software,
    or that it will be suitable for any particular purpose or for use
    under any specific conditions. Furthermore, the University disclaims
    all responsibility for the use which is made of the Software. It
    further disclaims any liability for the outcomes arising from using
    the Software.
    
    The Licensee agrees to indemnify the University and hold the
    University harmless from and against any and all claims, damages and
    liabilities asserted by third parties (including claims for
    negligence) which arise directly or indirectly from the use of the
    Software or the sale of any products based on the Software.
    
    No part of the Software may be reproduced, modified, transmitted or
    transferred in any form or by any means, electronic or mechanical,
    without the express permission of the University. The permission of
    the University is not required if the said reproduction, modification,
    transmission or transference is done without financial return, the
    conditions of this Licence are imposed upon the receiver of the
    product, and all original and amended source code is included in any
    transmitted product. You may be held legally responsible for any
    copyright infringement that is caused or encouraged by your failure to
    abide by these terms and conditions.
    
    You are not permitted under this Licence to use this Software
    commercially. Use for which any financial return is received shall be
    defined as commercial use, and includes (1) integration of all or part
    of the source code or the Software into a product for sale or license
    by or on behalf of Licensee to third parties or (2) use of the
    Software or any derivative of it for research with the final aim of
    developing software products for sale or license to a third party or
    (3) use of the Software or any derivative of it for research with the
    final aim of developing non-software products for sale or license to a
    third party, or (4) use of the Software to provide any service to an
    external organisation for which payment is received. If you are
    interested in using the Software commercially, please contact Isis
    Innovation Limited ("Isis"), the technology transfer company of the
    University, to negotiate a licence. Contact details are:
    innovation@isis.ox.ac.uk quoting reference DE/9564. */

#include <string>
#include <fstream>
#include <vector>
#include "newimage/newimageall.h"

using namespace NEWIMAGE;
using namespace MISCMATHS;
using namespace std;
 
int main(int argc, char **argv)
{
  vector<string> fileList;
  ifstream inputFile(argv[1]);
  string currentFile;

  while( getline( inputFile, currentFile ) )
     fileList.push_back( currentFile );

  Matrix design = read_vest("design.mat");
  int startingColumn=design.Ncols();

  Matrix meanRegressors;
  ofstream fileNames("vef.dat");
  ofstream fileNumbers("ven.dat");
  ofstream meanFile("meanConfounds.dat");

  for( unsigned int currentRegressor=0; currentRegressor < fileList.size(); currentRegressor++ )
  {
    fileNumbers << currentRegressor+startingColumn+1 << " ";
    fileNames << "confoundEV"+num2str(currentRegressor+1) << " ";
    volume4D<double> inputImage;
    read_volume4D(inputImage,fileList[currentRegressor]);
    save_volume4D(inputImage,"confoundEV"+num2str(currentRegressor+1));
    if ( currentRegressor==0 )
      meanRegressors.ReSize(inputImage.tsize(),fileList.size());
    for ( int t=0; t<inputImage.tsize(); t++ )
      meanRegressors(t+1,currentRegressor+1)=inputImage[t].mean();
  }
  meanFile << meanRegressors;
}

==> fsl_5.0.8.orig.tar.gz: fsl-5.0.8.orig/src/feat5/generateConfounds.cc <==
/*    Copyright Matthew Webster (C) 2012 University of Oxford  */

/*  Part of FSL - FMRIB's Software Library
    http://www.fmrib.ox.ac.uk/fsl
    fsl@fmrib.ox.ac.uk
    
    Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
    Imaging of the Brain), Department of Clinical Neurology, Oxford
    University, Oxford, UK
    
    
    LICENCE
    
    FMRIB Software Library, Release 5.0 (c) 2012, The University of
    Oxford (the "Software")
    
    The Software remains the property of the University of Oxford ("the
    University").
    
    The Software is distributed "AS IS" under this Licence solely for
    non-commercial use in the hope that it will be useful, but in order
    that the University as a charitable foundation protects its assets for
    the benefit of its educational and research purposes, the University
    makes clear that no condition is made or to be implied, nor is any
    warranty given or to be implied, as to the accuracy of the Software,
    or that it will be suitable for any particular purpose or for use
    under any specific conditions. Furthermore, the University disclaims
    all responsibility for the use which is made of the Software. It
    further disclaims any liability for the outcomes arising from using
    the Software.
    
    The Licensee agrees to indemnify the University and hold the
    University harmless from and against any and all claims, damages and
    liabilities asserted by third parties (including claims for
    negligence) which arise directly or indirectly from the use of the
    Software or the sale of any products based on the Software.
    
    No part of the Software may be reproduced, modified, transmitted or
    transferred in any form or by any means, electronic or mechanical,
    without the express permission of the University. The permission of
    the University is not required if the said reproduction, modification,
    transmission or transference is done without financial return, the
    conditions of this Licence are imposed upon the receiver of the
    product, and all original and amended source code is included in any
    transmitted product. You may be held legally responsible for any
    copyright infringement that is caused or encouraged by your failure to
    abide by these terms and conditions.
    
    You are not permitted under this Licence to use this Software
    commercially. Use for which any financial return is received shall be
    defined as commercial use, and includes (1) integration of all or part
    of the source code or the Software into a product for sale or license
    by or on behalf of Licensee to third parties or (2) use of the
    Software or any derivative of it for research with the final aim of
    developing software products for sale or license to a third party or
    (3) use of the Software or any derivative of it for research with the
    final aim of developing non-software products for sale or license to a
    third party, or (4) use of the Software to provide any service to an
    external organisation for which payment is received. If you are
    interested in using the Software commercially, please contact Isis
    Innovation Limited ("Isis"), the technology transfer company of the
    University, to negotiate a licence. Contact details are:
    innovation@isis.ox.ac.uk quoting reference DE/9564. */

#include <string>
#include <fstream>
#include <vector>
#include "newimage/newimageall.h"

using namespace NEWIMAGE;
using namespace MISCMATHS;
using namespace std;
 
int main(int argc, char **argv)
{
  vector<string> fileList;
  ifstream inputFile(argv[1]);
  string currentFile;

  while( getline( inputFile, currentFile ) )
     fileList.push_back( currentFile );

  Matrix design = read_vest("design.mat");
  int startingColumn=design.Ncols();

  Matrix meanRegressors;
  ofstream fileNames("vef.dat");
  ofstream fileNumbers("ven.dat");
  ofstream meanFile("meanConfounds.dat");

  for( unsigned int currentRegressor=0; currentRegressor < fileList.size(); currentRegressor++ )
  {
    string seperator;
    if ( currentRegressor != fileList.size()-1 )
      seperator=",";
    fileNumbers << currentRegressor+startingColumn+1 << seperator;
    fileNames << "confoundEV"+num2str(currentRegressor+1) << seperator;
    volume4D<double> inputImage;
    read_volume4D(inputImage,fileList[currentRegressor]);
    save_volume4D(inputImage,"confoundEV"+num2str(currentRegressor+1));
    if ( currentRegressor==0 )
      meanRegressors.ReSize(inputImage.tsize(),fileList.size());
    for ( int t=0; t<inputImage.tsize(); t++ )
      meanRegressors(t+1,currentRegressor+1)=inputImage[t].mean();
  }
  meanFile << meanRegressors;
}
